#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-1pXxC2Rpz7LfV25sGPvdD
key:                  gi-gtk-hs-0.3.17-1pXxC2Rpz7LfV25sGPvdD
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  90b6e95db78ad4fd8e05a0766be5ac34
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-1pXxC2Rpz7LfV25sGPvdD
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    containers-0.6.7 gi-gdk-3.0.29-CDloiv1P8C9aLRlfdeIXq
    gi-gdkpixbuf-2.0.32-1ZVb3E52J0c2othWuBicN
    gi-glib-2.0.30-IAA8FToHeoq3qfmQcLKXGZ
    gi-gobject-2.0.31-IypX1TMxjt23U3wRxisNnZ
    gi-gtk-3.0.43-LxnFdBpua0A4g8hFPzCzxg
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

